==> crewplus-0.1.0.tar.gz: crewplus-0.1.0/README.md <==
# CrewPlus

[![PyPI version](https://badge.fury.io/py/crewplus.svg)](https://badge.fury.io/py/crewplus)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/pypi/pyversions/crewplus.svg)](https://pypi.org/project/crewplus)
[![Build Status](https://img.shields.io/travis/com/your-org/crewplus-base.svg)](https://travis-ci.com/your-org/crewplus-base)

**CrewPlus** provides the foundational services and core components for building advanced AI applications. It is the heart of the CrewPlus ecosystem, designed for scalability, extensibility, and seamless integration.

## Overview

This repository, `crewplus-base`, contains the core `crewplus` Python package. It includes essential building blocks for interacting with large language models, managing vector databases, and handling application configuration. Whether you are building a simple chatbot or a complex multi-agent system, CrewPlus offers the robust foundation you need.

## The CrewPlus Ecosystem

CrewPlus is designed as a modular and extensible ecosystem of packages. This allows you to adopt only the components you need for your specific use case.

-   **`crewplus` (This package):** The core package containing foundational services for chat, model load balancing, and vector stores.
-   **`crewplus-agents`:** An extension for creating and managing autonomous AI agents.
-   **`crewplus-ingestion`:** Provides robust pipelines for knowledge ingestion and data processing.
-   **`crewplus-integrations`:** A collection of third-party integrations to connect CrewPlus with other services and platforms.
-   **`crewplus-enterprise`:** Enterprise-grade features for security, scalability, and support.

## Features

-   **Chat Services:** A unified interface for interacting with various chat models (e.g., `GeminiChatModel`).
-   **Model Load Balancer:** Intelligently distribute requests across multiple LLM endpoints.
-   **Vector DB Services:** Abstractions for working with popular vector stores for retrieval-augmented generation (RAG).
-   **Centralized Configuration:** Manage application settings and secrets from a single source of truth (`core/config.py`).

## Installation

To install the core `crewplus` package, run the following command:

```bash
pip install crewplus
```

## Getting Started

Here is a simple example of how to use the `GeminiChatModel` to start a conversation with an AI model.

```python
# main.py
from crewplus.services import GeminiChatModel

# Initialize the llm (API keys are typically handled by the configuration module)
llm = GeminiChatModel(google_api_key="your-google-api-key")

# Start a conversation
response = llm.chat("Hello, what is CrewPlus?")

print(response)
```

## Project Structure

The `crewplus-base` repository is organized to separate core logic, tests, and documentation. 

```
crewplus-base/                    # GitHub repo 名称
├── pyproject.toml
├── README.md
├── LICENSE
├── CHANGELOG.md
├── crewplus/                 # PyPI包名对应的目录
│   └──  __init__.py
│   └──  services/
│       └──  __init__.py
│       └──  gemini_chat_model.py
│       └──  model_load_balancer.py
│       └──  vdb_service.py
│       └──  ...
│   └──  vectorstores/
│       └──  ...
│   └──  core/
│       └──  __init__.py
│       └──  config.py
│       └──  ...
├── tests/
│   └── ...
└── notebooks/
    └── ...

```

## Deploy to PyPI
# install deployment tool
pip install twine

# build package
python -m build

# deploy to TestPyPI (Test first)
python -m twine upload --repository testpypi dist/*

# install from TestPyPI 
pip install -i https://test.pypi.org/simple/ crewplus

# Deploy to official PyPI
python -m twine upload dist/*

==> crewplus-0.1.1.tar.gz: crewplus-0.1.1/README.md <==
# CrewPlus

[![PyPI version](https://badge.fury.io/py/crewplus.svg)](https://badge.fury.io/py/crewplus)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/pypi/pyversions/crewplus.svg)](https://pypi.org/project/crewplus)
[![Build Status](https://img.shields.io/travis/com/your-org/crewplus-base.svg)](https://travis-ci.com/your-org/crewplus-base)

**CrewPlus** provides the foundational services and core components for building advanced AI applications. It is the heart of the CrewPlus ecosystem, designed for scalability, extensibility, and seamless integration.

## Overview

This repository, `crewplus-base`, contains the core `crewplus` Python package. It includes essential building blocks for interacting with large language models, managing vector databases, and handling application configuration. Whether you are building a simple chatbot or a complex multi-agent system, CrewPlus offers the robust foundation you need.

## The CrewPlus Ecosystem

CrewPlus is designed as a modular and extensible ecosystem of packages. This allows you to adopt only the components you need for your specific use case.

-   **`crewplus` (This package):** The core package containing foundational services for chat, model load balancing, and vector stores.
-   **`crewplus-agents`:** An extension for creating and managing autonomous AI agents.
-   **`crewplus-ingestion`:** Provides robust pipelines for knowledge ingestion and data processing.
-   **`crewplus-integrations`:** A collection of third-party integrations to connect CrewPlus with other services and platforms.
-   **`crewplus-enterprise`:** Enterprise-grade features for security, scalability, and support.

## Features

-   **Chat Services:** A unified interface for interacting with various chat models (e.g., `GeminiChatModel`).
-   **Model Load Balancer:** Intelligently distribute requests across multiple LLM endpoints.
-   **Vector DB Services:** Abstractions for working with popular vector stores for retrieval-augmented generation (RAG).
-   **Centralized Configuration:** Manage application settings and secrets from a single source of truth (`core/config.py`).

## Installation

To install the core `crewplus` package, run the following command:

```bash
pip install crewplus
```

## Getting Started

Here is a simple example of how to use the `GeminiChatModel` to start a conversation with an AI model.

```python
# main.py
from crewplus.services import GeminiChatModel

# Initialize the llm (API keys are typically handled by the configuration module)
llm = GeminiChatModel(google_api_key="your-google-api-key")

# Start a conversation
response = llm.chat("Hello, what is CrewPlus?")

print(response)
```

## Project Structure

The `crewplus-base` repository is organized to separate core logic, tests, and documentation. 

```
crewplus-base/                    # GitHub repo name
├── pyproject.toml
├── README.md
├── LICENSE
├── CHANGELOG.md
├── crewplus/                 # PyPI package name
│   └──  __init__.py
│   └──  services/
│       └──  __init__.py
│       └──  gemini_chat_model.py
│       └──  model_load_balancer.py
│       └──  vdb_service.py
│       └──  ...
│   └──  vectorstores/
│       └──  ...
│   └──  core/
│       └──  __init__.py
│       └──  config.py
│       └──  ...
├── tests/
│   └── ...
└── notebooks/
    └── ...

```

## Deploy to PyPI
# install deployment tool
pip install twine

# build package
python -m build

# deploy to TestPyPI (Test first)
python -m twine upload --repository testpypi dist/*

# install from TestPyPI 
pip install -i https://test.pypi.org/simple/ crewplus

# Deploy to official PyPI
python -m twine upload dist/*
